

def list(survey_id, *args, **kwargs):
    """ Get list of all responses for a survey.

        Optional params:
        - page:             page number
        - resultsperpage:   number of results per page
    """
    tail = "survey/%s/surveyresponse" % survey_id
    params = {

    }
    params.update(kwargs)
    return tail, params


def get(survey_id, response_id, *args, **kwargs):
    """ Get surveyresponse by id.

        Required params:
        - survey_id:    survey ID
        - response_id:  response ID
    """
    tail = "survey/%s/surveyresponse/%s" % (survey_id, response_id)
    params = {

    }
    params.update(kwargs)
    return tail, params


def create(survey_id, *args, **kwargs):
    """ Create new surveyresponse object.

        Required params:
        - survey_id:    survey ID

        Optional params:
        - data:         refer to official documentation
    """
    tail = "survey/%s/surveyresponse" % survey_id
    params = {
        '_method': 'PUT',
    }
    params.update(kwargs)
    return tail, params


def delete(survey_id, response_id, *args, **kwargs):
    """ Delete surveyresponse object.

        Required params:
        - survey_id: survey ID
        - response_id:  response ID
    """
    tail = "survey/%s/surveyresponse/%s" % (survey_id, response_id)
    params = {
        '_method': 'DELETE',
    }
    params.update(kwargs)
    return tail, params


def change(survey_id, response_id, *args, **kwargs):
    """ Change existing surveyresponse object.

        Required params:
        - survey_id:    survey ID
        - response_id:  response ID

        Optional params:
        - data:         refer to official documentation
    """
    tail = "survey/%s/surveyresponse/%s" % (survey_id, response_id)
    params = {
        '_method': 'POST',
    }
    params.update(kwargs)
    return tail, params





def list(survey_id, question_id, *args, **kwargs):
    """ Get list of all options for a surveyquestion.

        Required params:
        - survey_id:    survey ID
        - question_id:  question ID

        Optional params:
        - page:             page number
        - resultsperpage:   number of results per page
    """
    tail = "survey/%s/surveyquestion/%s/surveyoption" % (survey_id, question_id)
    params = {

    }
    params.update(kwargs)
    return tail, params


def get(survey_id, question_id, option_id, *args, **kwargs):
    """ Get surveyoption by id.

        Required params:
        - survey_id:    survey ID
        - question_id:  question ID
        - option_id:    option ID
    """
    tail = "survey/%s/surveyquestion/%s/surveyoption/%s" % (survey_id, question_id, option_id)
    params = {

    }
    params.update(kwargs)
    return tail, params


def create(survey_id, question_id, *args, **kwargs):
    """ Create new surveyoption object.

        Required params:
        - survey_id:    survey ID
        - question_id:  question ID

        Optional params:
        - title:        option title
        - value:        option value
    """
    tail = "survey/%s/surveyquestion%s/surveyoption" % (survey_id, question_id)
    params = {
        '_method': 'PUT',
    }
    params.update(kwargs)
    return tail, params


def delete(survey_id, question_id, option_id, *args, **kwargs):
    """ Delete surveyoption object.

        Required params:
        - survey_id:    survey ID
        - question_id:  question ID
        - option_id:    option ID
    """
    tail = "survey/%s/surveyquestion/%s/surveyoption/%s" % (survey_id, question_id, option_id)
    params = {
        '_method': 'DELETE',
    }
    params.update(kwargs)
    return tail, params


def change(survey_id, question_id, option_id, *args, **kwargs):
    """ Change existing surveyoption object.

        Required params:
        - survey_id:    survey ID
        - question_id:  question ID
        - option_id:    option ID

        Optional params:
        - title:        option title
        - value:        option value
    """
    tail = "survey/%s/surveyquestion/%s/surveyoption/%s" % (survey_id, question_id, option_id)
    params = {
        '_method': 'POST',
    }
    params.update(kwargs)
    return tail, params





def list(*args, **kwargs):
    """ Get list of all account users.

        Optional params:
        - page:             page number
        - resultsperpage:   number of results per page
    """
    return "accountuser/", {}


def get(accountuser_id, *args, **kwargs):
    """ Get account user by id.

        Required params:
        - accountuser_id:    account user ID
    """
    tail = "accountuser/%s" % accountuser_id
    params = {

    }
    params.update(kwargs)
    return tail, params


def create(email, *args, **kwargs):
    """ Create new accountuser object.

        Required params:
        - email:                email address

        Optional params:
        - username:             username
        - password:             password
        - team:                 team ID
        - create_access_token:  only allowed when using oauth
    """
    tail = "accountuser/"
    params = {
        '_method': 'PUT',
        'email': email,
    }
    params.update(kwargs)
    return tail, params


def change(accountuser_id, *args, **kwargs):
    """ Change existing accountuser object.

        Required params:
        - accountuser_id:       accountuser ID

        Optional params:
        - email:                email address
        - username:             username
        - password:             password
        - team:                 team ID
    """
    tail = "accountuser/%s" % accountuser_id
    params = {
        '_method': 'POST',
    }
    params.update(kwargs)
    return tail, params


def copy(accountuser_id, email, *args, **kwargs):
    """ Copy new account user object from existing account user.

        Required params:
        - accountuser_id:       account user ID
        - email:                email address

        Optional params:
        - username:             username
        - password:             password
        - team:                 team ID
    """
    tail = "accountuser/%s" % accountuser_id
    params = {
        '_method': 'POST',
        'email': email,
        'copy': 'true',
    }
    params.update(kwargs)
    return tail, params


def delete(accountuser_id, *args, **kwargs):
    """ Delete account user object.

        Required params:
        - accountuser_id:       accountuser ID
    """
    tail = "accountuser/%s" % accountuser_id
    params = {
        '_method': 'DELETE',
    }
    params.update(kwargs)
    return tail, params





def list(survey_id, *args, **kwargs):
    """ Get list of all campaigns for a survey.

        Required params:
        - survey_id:    survey ID

        Optional params:
        - page:             page number
        - resultsperpage:   number of results per page
    """
    tail = "survey/%s/surveycampaign" % survey_id
    params = {

    }
    params.update(kwargs)
    return tail, params


def get(survey_id, campaign_id, *args, **kwargs):
    """ Get surveycampaign by id.

        Required params:
        - survey_id:    survey ID
        - campaign_id:  campaign ID
    """
    tail = "survey/%s/surveycampaign/%s" % (survey_id, campaign_id)
    params = {

    }
    params.update(kwargs)
    return tail, params


def create(survey_id, campaign_type, *args, **kwargs):
    """ Create new surveycampaign object.

        Required params:
        - survey_id         survey ID
        - campaign_type     select from [link, email, html, js, blog, iframe, popup ...]

        Optional params:
        - name:         name of the campaign
        - language:     language of the campaign [Auto, English...]
        - status:       select from [Active, Closed, Deleted]
        - slug:         url slug for the campaign
        - subtype:      distribution link subtype (private), Ex: &subtype=private
    """

    tail = "survey/%s/surveycampaign/type/%s" % (survey_id, campaign_type)
    params = {
        '_method': 'PUT',
    }
    params.update(kwargs)
    return tail, params


def change(survey_id, campaign_id, *args, **kwargs):
    """ Change existing surveycampaign object.

        Required params:
        - survey_id:    survey ID
        - campaign_id:  campaign ID

        Optional params:
        - name:         name of the campaign
        - language:     language of the campaign [Auto, English...]
        - status:       select from [Active, Closed, Deleted]
        - slug:         url slug for the campaign
    """
    tail = "survey/%s/surveycampaign/%s" % (survey_id, campaign_id)
    params = {
        '_method': 'POST',
    }
    params.update(kwargs)
    return tail, params


def copy(survey_id, campaign_id, *args, **kwargs):
    """ Copy new surveycampaign object from existing surveycampaign.

        Required params:
        - survey_id:    survey ID
        - campaign_id:  campaign ID

        Optional params:
        - id:           link ID of the campaign
        - name:         name of the campaign
    """
    tail = "survey/%s/surveycampaign/%s" % (survey_id, campaign_id)
    params = {
        '_method': 'POST',
        'copy': 'true',
    }
    params.update(kwargs)
    return tail, params


def delete(survey_id, campaign_id, *args, **kwargs):
    """ Delete surveycampaign object.

        Required params:
        - survey_id: survey ID
        - campaign_id:  campaign ID
    """
    tail = "survey/%s/surveycampaign/%s" % (survey_id, campaign_id)
    params = {
        '_method': 'DELETE',
    }
    params.update(kwargs)
    return tail, params




__all__ = [
    'account',
    'accountteams',
    'accountuser',
    # 'contact',
    # 'contactlist',
    # 'emailmessage',
    'survey',
    'surveycampaign',
    'surveypage',
    'surveyquestion',
    'surveyresponse',
    'surveystatistic',
]
